// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

syntax = "proto3";

package google.maps.mapsplatformdatasets.v1alpha;

import "google/api/field_behavior.proto";
import "google/api/resource.proto";
import "google/maps/mapsplatformdatasets/v1alpha/data_source.proto";
import "google/protobuf/timestamp.proto";

option csharp_namespace = "Google.Maps.MapsPlatformDatasets.V1Alpha";
option go_package = "cloud.google.com/go/maps/mapsplatformdatasets/apiv1alpha/mapsplatformdatasetspb;mapsplatformdatasetspb";
option java_multiple_files = true;
option java_outer_classname = "DatasetProto";
option java_package = "com.google.maps.mapsplatformdatasets.v1alpha";
option php_namespace = "Google\\Maps\\MapsPlatformDatasets\\V1alpha";

// A representation of a maps platform dataset.
message Dataset {
  option (google.api.resource) = {
    type: "mapsplatformdatasets.googleapis.com/Dataset"
    pattern: "projects/{project}/datasets/{dataset}"
  };

  // Resource name,
  // projects/{project}/datasets/{dataset_id}
  string name = 1;

  // Human readable name, shown in the console UI. Set by customer.
  string display_name = 2;

  // A description of this dataset; set by the customer.
  string description = 3;

  // The version of the dataset.
  string version_id = 4;

  // Specified use case(s) for this dataset.
  repeated Usage usage = 5;

  // Details about the source of the data for the dataset.
  oneof data_source {
    // A local file source for the dataset for a single upload.
    LocalFileSource local_file_source = 6;

    // A Google Cloud Storage file source for the dataset for a single upload.
    GcsSource gcs_source = 7;
  }

  // The status of the import of the latest dataset version.
  State status = 12;

  // Output only. Time when the dataset was first created.
  google.protobuf.Timestamp create_time = 8 [(google.api.field_behavior) = OUTPUT_ONLY];

  // Output only. Time when the dataset metadata was last updated.
  google.protobuf.Timestamp update_time = 9 [(google.api.field_behavior) = OUTPUT_ONLY];

  // Output only. Time when this version of dataset was created. (It happened when importing
  // data to the dataset)
  google.protobuf.Timestamp version_create_time = 10 [(google.api.field_behavior) = OUTPUT_ONLY];

  // Output only. The description for this version of dataset. It is provided when importing
  // data to the dataset.
  string version_description = 11 [(google.api.field_behavior) = OUTPUT_ONLY];
}

// Usage specifies where the data is intended to be used to inform how to
// process the data.
enum Usage {
  // The usage of this dataset is not set.
  USAGE_UNSPECIFIED = 0;

  // This dataset will be used for data driven styling.
  USAGE_DATA_DRIVEN_STYLING = 1;

  // This dataset will be used for area affordances in routing.
  USAGE_AREA_AFFORDANCES = 2;

  // This dataset will be used for assisted driving in routing.
  USAGE_ASSISTED_DRIVING = 3;
}

// State specifies the status of the import of the latest dataset version.
enum State {
  // The state of this dataset is not set.
  STATE_UNSPECIFIED = 0;

  // The dataset version is getting imported.
  STATE_IMPORTING = 1;

  // The dataset version succeeded in getting imported.
  STATE_IMPORT_SUCCEEDED = 2;

  // The dataset version failed to get imported.
  STATE_IMPORT_FAILED = 3;
}
